@@ -2,12 +2,14 @@ mod bucket;
 mod comments;
 mod dataset;
 mod emails;
+mod project;
 mod source;
 mod user;
 
 use self::{
     bucket::CreateBucketArgs, comments::CreateCommentsArgs, dataset::CreateDatasetArgs,
-    emails::CreateEmailsArgs, source::CreateSourceArgs, user::CreateUserArgs,
+    emails::CreateEmailsArgs, project::CreateProjectArgs, source::CreateSourceArgs,
+    user::CreateUserArgs,
 };
 use crate::printer::Printer;
 use anyhow::Result;
@@ -20,6 +22,10 @@ pub enum CreateArgs {
     /// Create a new bucket
     Bucket(CreateBucketArgs),
 
+    #[structopt(name = "project")]
+    /// Create a new project
+    Project(CreateProjectArgs),
+
     #[structopt(name = "source")]
     /// Create a new source
     Source(CreateSourceArgs),
@@ -46,6 +52,7 @@ pub fn run(create_args: &CreateArgs, client: Client, printer: &Printer) -> Resul
         CreateArgs::Bucket(bucket_args) => bucket::create(&client, bucket_args, printer),
         CreateArgs::Source(source_args) => source::create(&client, source_args, printer),
         CreateArgs::Dataset(dataset_args) => dataset::create(&client, dataset_args, printer),
+        CreateArgs::Project(project_args) => project::create(&client, project_args, printer),
         CreateArgs::Comments(comments_args) => comments::create(&client, comments_args),
         CreateArgs::Emails(emails_args) => emails::create(&client, emails_args),
         CreateArgs::User(user_args) => user::create(&client, user_args, printer),
