@@ -1,7 +1,7 @@
 use crate::printer::Printer;
 use anyhow::{Context, Result};
 use log::info;
-use reinfer_client::{BucketId, BucketIdentifier, Client, SourceIdentifier, UpdateSource};
+use reinfer_client::{BucketIdentifier, Client, SourceIdentifier, UpdateSource};
 use structopt::StructOpt;
 
 #[derive(Debug, StructOpt)]
@@ -29,28 +29,23 @@ pub struct UpdateSourceArgs {
 
 pub fn update(client: &Client, args: &UpdateSourceArgs, printer: &Printer) -> Result<()> {
     let UpdateSourceArgs {
-        ref source,
-        ref title,
-        ref description,
-        ref should_translate,
-        ref bucket,
-    } = *args;
+        source,
+        title,
+        description,
+        should_translate,
+        bucket,
+    } = args;
 
-    let bucket_id = bucket
-        .as_ref()
-        .map(Clone::clone)
-        .map(|bucket| -> Result<BucketId> {
-            Ok(match bucket {
-                BucketIdentifier::Id(bucket_id) => bucket_id,
-                BucketIdentifier::FullName(_) => {
-                    client
-                        .get_bucket(bucket)
-                        .context("Fetching bucket for id.")?
-                        .id
-                }
-            })
-        })
-        .transpose()?;
+    let bucket_id = match bucket.to_owned() {
+        Some(BucketIdentifier::Id(bucket_id)) => Some(bucket_id),
+        Some(full_name @ BucketIdentifier::FullName(_)) => Some(
+            client
+                .get_bucket(full_name)
+                .context("Fetching bucket for id.")?
+                .id,
+        ),
+        None => None,
+    };
 
     let source_full_name = match source.to_owned() {
         SourceIdentifier::FullName(name) => name,
@@ -64,8 +59,8 @@ pub fn update(client: &Client, args: &UpdateSourceArgs, printer: &Printer) -> Re
         .update_source(
             &source_full_name,
             UpdateSource {
-                title: title.as_ref().map(|title| title.as_str()),
-                description: description.as_ref().map(|description| description.as_str()),
+                title: title.as_deref(),
+                description: description.as_deref(),
                 should_translate: *should_translate,
                 bucket_id,
                 sensitive_properties: None,
